Index: samples/swarm/App.dart |
diff --git a/samples/swarm/App.dart b/samples/swarm/App.dart |
index 2837320a1de5c78028cf056780a3800701ee550e..376a17d3dbd2069a1dc76fe57d43f2015b93c9e3 100644 |
--- a/samples/swarm/App.dart |
+++ b/samples/swarm/App.dart |
@@ -27,9 +27,9 @@ class App { |
if (document.readyState == "interactive" || |
document.readyState == "complete" || |
document.readyState == "loaded") { |
// We use setTimeout to insure that onLoad is always called in an async |
// manner even if the document is already loaded. |
- window.setTimeout(() => onLoad(), 0); |
+ Timer.run(onLoad); |
} else { |
window.onContentLoaded.listen( |
// TODO(sigmund): Consider eliminating the call to "wrap", for |
@@ -27,9 +27,9 @@ class App { |
document.readyState == "complete" || |
document.readyState == "loaded") { |
- // We use setTimeout to insure that onLoad is always called in an async |
+ // We use a timer to insure that onLoad is always called in an async |
// manner even if the document is already loaded. |